#!/usr/bin/env bash

action() {

    # law + luigi env variables
    local base="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
    export LAW_HOME="$base/.law"
    export LAW_CONFIG_FILE="$base/law.cfg"
    export LUIGI_CONFIG_PATH="$base/luigi.cfg"
    export ANALYSIS_PATH="$base"
    export ANALYSIS_DATA_PATH="$ANALYSIS_PATH/data"

    # luigi + law
    export PATH="$base/law/bin:$base/luigi/bin:$PATH"
    export PYTHONPATH="$base/law:$base/luigi:$base/six:$base/python-dateutil-2.8.2:$base:$PYTHONPATH"

    # lcg software stack with python3 and gcc11 (use the same one as for cvmfs install of NNLOJET & APPLfast)
    source /cvmfs/sft.cern.ch/lcg/views/LCG_102/x86_64-centos7-gcc11-opt/setup.sh

    # fastNLO tools (perl and python scripts)
    # Required to merge fastwarm results or for plotting (needs python3, matplotlib3, numpy, scipy)
    # Add local paths to git checkout, e.g.
    gitpath="/storage/9/rabbertz/git/fastNLO"
    #gitpath="/eos/theory/project/applfast/git/fastNLO"
    export PATH="$gitpath/tools:$gitpath/tools/plotting:$PATH"

    # NNLOJET + APPLfast (cvmfs)
    applfastpath="/cvmfs/etp.kit.edu/fastnnlo-3034_bridge-1.0.1_202406_lcg105-c7-gcc11"
    #applfastpath="/eos/theory/project/applfast/local"
    # LCG not needed here since source'd already above!
    # NNLOJET & APPLfast
    source $applfastpath/src/fnlosrc_source.sh
    # Rivet
    source $applfastpath/src/rivetenv.sh
    # If fastNLO version of grid install in /cvmfs/etp.kit.edu not new enough for evaluation,
    # then use local install for plotting etc, but keep scripts of NNLOJET in PATH
    #export PATH="$applfastpath/src/NNLOJET_rev6591/driver/bin:$PATH"

    # Output path for local production output on lxplus; not required when using grid storage
    #export ANALYSIS_OUTPUT_PATH="$applfastpath/output"

    # fastNLO installation (local)
    # If grid install is too old or uses fastNLO extension compiled with python2
    # !!! Does not work on systems of ETP portals or lxplus with Centos7!
    # --> Either use your more modern Desktop PC e.g. with Ubuntu and properly set PATH and PYTHONPATH
    # --> or use install with lcg software stack from /cvmfs/sft.cern.ch/lcg/views
    # Here, lcg environment and PATH, PYTHONPATH are set from local installation file
    fnlopath="/work/rabbertz/local.lcg105-c7"
    #fnlopath="/eos/theory/project/applfast/local.py3"
    source $fnlopath/src/lcg105_source.sh   # LCG software stack
    source $fnlopath/src/fnlosrc_source.sh  # fastNLO
    source $fnlopath/src/rivetenv.sh        # Rivet

    # Use new modified nnlojet merging from fastNLO git
    export PATH="$gitpath/tools/nnlojet:$PATH"

    # grid storage interface with gfal2, if required
    # SLC6
    # source /cvmfs/grid.cern.ch/emi3ui-latest/etc/profile.d/setup-ui-example.sh
    # C7
    # source /cvmfs/grid.cern.ch/umd-c7ui-latest/etc/profile.d/setup-c7-ui-example.sh
    # C7 with python3
    # source /cvmfs/grid.cern.ch/centos7-ui-200122/etc/profile.d/setup-c7-ui-python3-example.sh
    source /cvmfs/grid.cern.ch/centos7-ui-160522/etc/profile.d/setup-c7-ui-python3-example.sh
    #
    # Proxy location on afs required by lxplus if using grid storage
    # export X509_USER_PROXY=/afs/cern.ch/user/k/krabbert/tmp/x509up_u7747

    source "$( law completion )"
}
action
